@@ -1,18 +1,17 @@
 use std::{env, io};
 
-use futures::future;
 use log::info;
 use ntex::http::header::HeaderValue;
 use ntex::http::{HttpService, Response};
-use ntex::{server::Server, time::Seconds};
+use ntex::{server::Server, time::Seconds, util::Ready};
 
 #[ntex::main]
 async fn main() -> io::Result<()> {
-    env::set_var("RUST_LOG", "hello_world=info");
+    env::set_var("RUST_LOG", "ntex=trace,hello_world=info");
     env_logger::init();
 
     Server::build()
-        .bind("hello-world", "127.0.0.1:8080", || {
+        .bind("hello-world", "127.0.0.1:8080", |_| {
             HttpService::build()
                 .client_timeout(Seconds(1))
                 .disconnect_timeout(Seconds(1))
@@ -20,9 +19,8 @@ async fn main() -> io::Result<()> {
                     info!("{:?}", _req);
                     let mut res = Response::Ok();
                     res.header("x-head", HeaderValue::from_static("dummy value!"));
-                    future::ok::<_, io::Error>(res.body("Hello world!"))
+                    Ready::Ok::<_, io::Error>(res.body("Hello world!"))
                 })
-                .tcp()
         })?
         .run()
         .await
