@@ -4,7 +4,7 @@ use log::debug;
 use nanorand::{Rng, WyRand};
 
 use super::proto::{CloseCode, CloseReason, OpCode};
-use super::{mask::apply_mask, ProtocolError};
+use super::{error::ProtocolError, mask::apply_mask};
 use crate::util::{Buf, BufMut, BytesMut};
 
 /// WebSocket frame parser.
@@ -77,8 +77,7 @@ impl Parser {
                 return Ok(None);
             }
 
-            let mask =
-                u32::from_le_bytes(TryFrom::try_from(&src[idx..idx + 4]).unwrap());
+            let mask = u32::from_le_bytes(TryFrom::try_from(&src[idx..idx + 4]).unwrap());
             idx += 4;
             Some(mask)
         } else {
@@ -235,16 +234,12 @@ mod tests {
         }
     }
 
-    fn extract(
-        frm: Result<Option<(bool, OpCode, Option<BytesMut>)>, ProtocolError>,
-    ) -> F {
+    fn extract(frm: Result<Option<(bool, OpCode, Option<BytesMut>)>, ProtocolError>) -> F {
         match frm {
             Ok(Some((finished, opcode, payload))) => F {
                 finished,
                 opcode,
-                payload: payload
-                    .map(|b| b.freeze())
-                    .unwrap_or_else(|| Bytes::from("")),
+                payload: payload.map(|b| b.freeze()).unwrap_or_else(Bytes::new),
             },
             _ => unreachable!("error"),
         }
